@@ -245,9 +245,9 @@ DataFrame importance_ls_cpp(
 //' @param distance (optional, character string) distance name from the "names"
 //' column of the dataset `distances` (see `distances$name`). Default: "euclidean".
 //' @param diagonal (optional, logical). If TRUE, diagonals are included in the
-//' computation of the cost matrix. Default: FALSE.
-//' @param weighted (optional, logical). If TRUE, diagonal is set to TRUE, and
-//' diagonal cost is weighted by a factor of 1.414214 (square root of 2). Default: FALSE.
+//' computation of the cost matrix. Default: TRUE.
+//' @param weighted (optional, logical). Only relevant when diagonal is TRUE. When TRUE,
+//' diagonal cost is weighted by y factor of 1.414214 (square root of 2). Default: TRUE.
 //' @param ignore_blocks (optional, logical). If TRUE, blocks of consecutive path
 //' coordinates are trimmed to avoid inflating the psi distance. Default: FALSE.
 //' @param bandwidth (required, numeric) Size of the Sakoe-Chiba band at
@@ -393,8 +393,8 @@ DataFrame importance_dtw_legacy_cpp(
 //' column of the dataset `distances` (see `distances$name`). Default: "euclidean".
 //' @param diagonal (optional, logical). If TRUE, diagonals are included in the
 //' computation of the cost matrix. Default: TRUE.
-//' @param weighted (optional, logical). If TRUE, diagonal is set to TRUE, and
-//' diagonal cost is weighted by a factor of 1.414214 (square root of 2). Default: TRUE.
+//' @param weighted (optional, logical). Only relevant when diagonal is TRUE. When TRUE,
+//' diagonal cost is weighted by y factor of 1.414214 (square root of 2). Default: TRUE.
 //' @param ignore_blocks (optional, logical). If TRUE, blocks of consecutive path
 //' coordinates are trimmed to avoid inflating the psi distance. Default: FALSE.
 //' @param bandwidth (required, numeric) Size of the Sakoe-Chiba band at
@@ -546,7 +546,7 @@ DataFrame importance_dtw_cpp(
     psi_difference[i] = psi_only_with[i] - psi_without[i];
 
     //psi drop as a percentage of psi_all_variables
-    importance[i] = (psi_difference[i] * 100) / psi_all_variables;
+    importance[i] = (psi_difference[i] * 100.0) / psi_all_variables;
 
   }
 
